# Aerodynamics
Pypi Project Aerodynamics for aircrafts, rockets and so on. 
Written by Dilara Ozev and Ethem Yilmaz.

#Aerodynamics 0.0.1 is going to be published in 09.03.2021
This is the first version of our package so we are very impassioned. In the first package of project, we have planned to publish a few functions 
that are essential to make calculations in aerospace field such as reynolds_number, sound of speed, mach_number and so forth.
